==> blesta-5.10.2.zip: blesta/plugins/domains/language/it_it/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.it_it
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.getmodulefields.auto_choose'] = '-- Scegliere Automaticamente --';
$lang['AdminMain.edit.title_basic_options'] = 'Opzioni di base';
$lang['AdminMain.edit.title_actions'] = 'Azioni';
$lang['AdminMain.edit.title_domain_information'] = 'Informazioni sul dominio';
$lang['AdminMain.edit.term_years'] = '%1$s Anni';
$lang['AdminMain.edit.term_year'] = '%1$s Anno';
$lang['AdminMain.edit.term_months'] = '%1$s Mesi';
$lang['AdminMain.edit.term_month'] = '%1$s Mese';
$lang['AdminMain.edit.term_weeks'] = '%1$s Settimane';
$lang['AdminMain.edit.term_week'] = 'Settimana %1$s';
$lang['AdminMain.edit.term_days'] = '%1$s Giorni';
$lang['AdminMain.edit.term_day'] = 'Giorno %1$s';
$lang['AdminMain.edit.text_date_canceled'] = 'Data di cancellazione:';
$lang['AdminMain.edit.text_date_suspended'] = 'Data di sospensione:';
$lang['AdminMain.edit.text_date_last_renewed'] = 'Data dell\'ultimo rinnovo:';
$lang['AdminMain.edit.text_never'] = 'Mai';
$lang['AdminMain.edit.text_date_expires'] = 'Data di scadenza:';
$lang['AdminMain.edit.text_date_renews'] = 'Data di rinnovo:';
$lang['AdminMain.edit.text_date_added'] = 'Data di creazione:';
$lang['AdminMain.edit.text_status'] = 'Stato:';
$lang['AdminMain.edit.text_years'] = 'Anni di registrazione:';
$lang['AdminMain.edit.text_registrar'] = 'Registrar:';
$lang['AdminMain.edit.text_domain'] = 'Dominio:';
$lang['AdminMain.edit.field_edit_service'] = 'Modifica del servizio';
$lang['AdminMain.edit.field_activate'] = 'Attivare';
$lang['AdminMain.edit.field_submit'] = 'Aggiornamento';
$lang['AdminMain.edit.field_notify_order'] = 'Invia un\'e-mail di conferma dell\'ordine quando viene attivato';
$lang['AdminMain.edit.field_use_module'] = 'Modulo d\'uso';
$lang['AdminMain.edit.field_module'] = 'Modulo Registrar';
$lang['AdminMain.edit.field_client'] = 'Cliente';
$lang['AdminMain.edit.field_ns5'] = 'Server dei nomi 5';
$lang['AdminMain.edit.field_ns4'] = 'Server dei nomi 4';
$lang['AdminMain.edit.field_ns3'] = 'Server dei nomi 3';
$lang['AdminMain.edit.field_ns2'] = 'Server dei nomi 2';
$lang['AdminMain.edit.field_ns1'] = 'Server dei nomi 1';
$lang['AdminMain.edit.field_auto_renewal'] = 'Abilita il rinnovo automatico';
$lang['AdminMain.edit.field_years'] = 'Anni';
$lang['AdminMain.edit.field_action'] = 'Azione';
$lang['AdminMain.edit.link_viewclient'] = 'Visualizza il cliente';
$lang['AdminMain.edit.boxtitle_edit'] = 'Modifica dominio: %1$s';
$lang['AdminMain.edit.boxtitle_client'] = 'Cliente #%1$s';
$lang['AdminMain.add_confirmation.discount'] = 'Sconto:';
$lang['AdminMain.add_confirmation.subtotal'] = 'Totale parziale:';
$lang['AdminMain.add_confirmation.price'] = 'Prezzo';
$lang['AdminMain.add_confirmation.qty'] = 'Quantità';
$lang['AdminMain.add_confirmation.description'] = 'Descrizione';
$lang['AdminMain.add_confirmation.type_transfer'] = 'Trasferimento';
$lang['AdminMain.add_confirmation.type_register'] = 'Registrazione';
$lang['AdminMain.add_confirmation.field_edit'] = 'Modifica';
$lang['AdminMain.add_confirmation.field_add'] = 'Aggiungi dominio';
$lang['AdminMain.add_confirmation.field_update_coupon'] = 'Aggiornamento';
$lang['AdminMain.add_confirmation.field_coupon_code'] = 'Codice coupon';
$lang['AdminMain.add_confirmation.field_price'] = 'Prezzo:';
$lang['AdminMain.add_confirmation.field_type'] = 'Tipo:';
$lang['AdminMain.add_confirmation.field_years'] = 'Anni:';
$lang['AdminMain.add_confirmation.field_domain'] = 'Dominio:';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = 'No';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = 'Sì';
$lang['AdminMain.add_confirmation.field_notify_order'] = 'Inviare l\'e-mail di conferma dell\'ordine:';
$lang['AdminMain.add_confirmation.field_module'] = 'Modulo Registrar:';
$lang['AdminMain.add_confirmation.field_status'] = 'Stato:';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = 'Non fatturare';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = 'Aggiungere alla fattura %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = 'Creare una nuova fattura';
$lang['AdminMain.add_confirmation.field_invoice_method'] = 'Metodo di fatturazione:';
$lang['AdminMain.add.edit_package_pricing'] = 'Modifica dei prezzi';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s (rinnova a %3$s)';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.order_btn'] = 'Ordine selezionato';
$lang['AdminMain.add.term_years'] = '%1$s Anni';
$lang['AdminMain.add.term_year'] = '%1$s Anno';
$lang['AdminMain.add.term_months'] = '%1$s Mesi';
$lang['AdminMain.add.term_month'] = '%1$s Mese';
$lang['AdminMain.add.term_weeks'] = '%1$s Settimane';
$lang['AdminMain.add.term_week'] = 'Settimana %1$s';
$lang['AdminMain.add.term_days'] = '%1$s Giorni';
$lang['AdminMain.add.term_day'] = 'Giorno %1$s';
$lang['AdminMain.add.text_domain_unavailable'] = 'Non disponibile';
$lang['AdminMain.add.text_domain_available'] = 'Disponibile';
$lang['AdminMain.add.heading_options'] = 'Opzioni';
$lang['AdminMain.add.heading_status'] = 'Stato';
$lang['AdminMain.add.heading_domain'] = 'Dominio';
$lang['AdminMain.add.title_registrar_options'] = 'Opzioni del conservatore';
$lang['AdminMain.add.title_basic_options'] = 'Opzioni di base';
$lang['AdminMain.add.title_search_results'] = 'Risultati della ricerca';
$lang['AdminMain.add.field_notify_order'] = 'Invia un\'e-mail di conferma dell\'ordine quando viene attivato';
$lang['AdminMain.add.field_use_module'] = 'Provisionare il dominio utilizzando il modulo della società di registrazione quando viene attivato';
$lang['AdminMain.add.field_module'] = 'Modulo Registrar';
$lang['AdminMain.add.field_status'] = 'Stato';
$lang['AdminMain.add.field_years'] = 'Anni';
$lang['AdminMain.add.field_invoice_method_dont'] = 'Non fatturare';
$lang['AdminMain.add.field_invoice_method_append'] = 'Aggiunta alla fattura esistente';
$lang['AdminMain.add.field_invoice_method_create'] = 'Creare una nuova fattura';
$lang['AdminMain.add.field_invoice_method'] = 'Metodo di fatturazione';
$lang['AdminMain.add.field_submit'] = 'Continua';
$lang['AdminMain.add.field_lookup'] = 'Verifica la disponibilità';
$lang['AdminMain.add.field_add'] = 'Aggiungi dominio';
$lang['AdminMain.add.field_register'] = 'Registro';
$lang['AdminMain.add.field_transfer'] = 'Trasferimento';
$lang['AdminMain.add.link_viewclient'] = 'Visualizza il cliente';
$lang['AdminMain.add.boxtitle_add'] = 'Aggiungi dominio: %1$s';
$lang['AdminMain.add.boxtitle_client'] = 'Cliente #%1$s';
$lang['AdminMain.index.unparent'] = 'Prezzo non genitore e prezzo di azzeramento';
$lang['AdminMain.!error.unsupported_domain'] = 'Il nome di dominio non è supportato.';
$lang['AdminMain.!success.service_edited'] = 'Il dominio è stato aggiornato con successo!';
$lang['AdminMain.!success.domain_add'] = 'Il dominio è stato aggiunto con successo!';
$lang['AdminMain.!success.domain_transfer'] = 'Il dominio è stato trasferito con successo!';
$lang['AdminMain.!success.domain_register'] = 'Il dominio è stato registrato con successo!';
$lang['AdminMain.!success.domains_unparented'] = 'I domini selezionati sono stati rimossi dai loro servizi madre e il prezzo è stato ripristinato con successo!';
$lang['AdminMain.getfilters.field_service_meta'] = 'Nome di dominio';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.any'] = 'Qualsiasi';
$lang['AdminMain.domains.action.field_client'] = 'Cliente';
$lang['AdminMain.domains.action.field_nameservers'] = 'Nameserver';
$lang['AdminMain.domains.action.field_years'] = 'Anni';
$lang['AdminMain.index.field_actionsubmit'] = 'Invia';
$lang['AdminMain.index.domain_push_to_client'] = 'Spinta al cliente';
$lang['AdminMain.index.update_nameservers'] = 'Aggiornare i server dei nomi';
$lang['AdminMain.index.domain_renewal'] = 'Rinnovo del dominio';
$lang['AdminMain.index.change_auto_renewal'] = 'Cambia il rinnovo dell\'auto';
$lang['AdminMain.index.text_off'] = 'Spento';
$lang['AdminMain.index.text_on'] = 'Su';
$lang['AdminMain.index.text_never'] = 'Mai';
$lang['AdminMain.index.no_results'] = 'Non ci sono servizi con questo status.';
$lang['AdminMain.index.confirm_delete'] = 'Siete sicuri di voler eliminare questo servizio?';
$lang['AdminMain.index.option_delete'] = 'Cancellare';
$lang['AdminMain.index.option_manage'] = 'Gestire';
$lang['AdminMain.index.option_parent'] = 'Genitore';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.categorylink_newservice'] = 'Nuovo dominio';
$lang['AdminMain.index.category_canceled'] = 'Annullato';
$lang['AdminMain.index.category_suspended'] = 'Sospeso';
$lang['AdminMain.index.category_pending'] = 'In attesa';
$lang['AdminMain.index.category_active'] = 'Attivo';
$lang['AdminMain.index.heading_options'] = 'Opzioni';
$lang['AdminMain.index.heading_datecanceled'] = 'Data di annullamento';
$lang['AdminMain.index.heading_datesuspended'] = 'Data di sospensione';
$lang['AdminMain.index.heading_dateexpires'] = 'Data di scadenza';
$lang['AdminMain.index.heading_daterenews'] = 'Data Rinnovo';
$lang['AdminMain.index.heading_datecreated'] = 'Data di creazione';
$lang['AdminMain.index.heading_term'] = 'Termine';
$lang['AdminMain.index.heading_domain'] = 'Dominio';
$lang['AdminMain.index.heading_status'] = 'Stato';
$lang['AdminMain.index.heading_addons'] = 'Componenti aggiuntivi';
$lang['AdminMain.index.boxtitle_domains'] = 'Domini';
$lang['AdminMain.index.page_title'] = 'Dominio del cliente #%1$s';
$lang['AdminMain.!success.domains_pushed'] = 'I domini selezionati sono stati trasferiti con successo al nuovo client.';
$lang['AdminMain.!success.update_nameservers'] = 'I server dei nomi di dominio sono stati aggiornati!';
$lang['AdminMain.!success.domain_renewal'] = 'Il dominio è stato rinnovato!';
$lang['AdminMain.!success.change_auto_renewal'] = 'Il rinnovo automatico del dominio è stato aggiornato!';
$lang['AdminMain.edit.text_registration_date'] = 'Data di registrazione:';
$lang['AdminMain.index.text_date_added'] = 'Data di inserimento:';
$lang['AdminMain.index.heading_dateregistration'] = 'Data di registrazione';
$lang['AdminMain.index.heading_registrar'] = 'Registrar';
$lang['AdminMain.!success.domain_registrar_updated'] = 'Il registrar del dominio è stato aggiornato!';

==> blesta-5.11.4.zip: blesta/plugins/domains/language/it_it/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.it_it
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.getmodulefields.auto_choose'] = '-- Scegliere Automaticamente --';
$lang['AdminMain.edit.title_basic_options'] = 'Opzioni di base';
$lang['AdminMain.edit.title_actions'] = 'Azioni';
$lang['AdminMain.edit.title_domain_information'] = 'Informazioni sul dominio';
$lang['AdminMain.edit.term_years'] = '%1$s Anni';
$lang['AdminMain.edit.term_year'] = '%1$s Anno';
$lang['AdminMain.edit.term_months'] = '%1$s Mesi';
$lang['AdminMain.edit.term_month'] = '%1$s Mese';
$lang['AdminMain.edit.term_weeks'] = '%1$s Settimane';
$lang['AdminMain.edit.term_week'] = 'Settimana %1$s';
$lang['AdminMain.edit.term_days'] = '%1$s Giorni';
$lang['AdminMain.edit.term_day'] = 'Giorno %1$s';
$lang['AdminMain.edit.text_date_canceled'] = 'Data di cancellazione:';
$lang['AdminMain.edit.text_date_suspended'] = 'Data di sospensione:';
$lang['AdminMain.edit.text_date_last_renewed'] = 'Data dell\'ultimo rinnovo:';
$lang['AdminMain.edit.text_never'] = 'Mai';
$lang['AdminMain.edit.text_date_expires'] = 'Data di scadenza:';
$lang['AdminMain.edit.text_date_renews'] = 'Data di rinnovo:';
$lang['AdminMain.edit.text_date_added'] = 'Data di creazione:';
$lang['AdminMain.edit.text_status'] = 'Stato:';
$lang['AdminMain.edit.text_years'] = 'Anni di registrazione:';
$lang['AdminMain.edit.text_registrar'] = 'Registrar:';
$lang['AdminMain.edit.text_domain'] = 'Dominio:';
$lang['AdminMain.edit.field_edit_service'] = 'Modifica del servizio';
$lang['AdminMain.edit.field_activate'] = 'Attivare';
$lang['AdminMain.edit.field_submit'] = 'Aggiornamento';
$lang['AdminMain.edit.field_notify_order'] = 'Invia un\'e-mail di conferma dell\'ordine quando viene attivato';
$lang['AdminMain.edit.field_use_module'] = 'Modulo d\'uso';
$lang['AdminMain.edit.field_module'] = 'Modulo Registrar';
$lang['AdminMain.edit.field_client'] = 'Cliente';
$lang['AdminMain.edit.field_ns5'] = 'Server dei nomi 5';
$lang['AdminMain.edit.field_ns4'] = 'Server dei nomi 4';
$lang['AdminMain.edit.field_ns3'] = 'Server dei nomi 3';
$lang['AdminMain.edit.field_ns2'] = 'Server dei nomi 2';
$lang['AdminMain.edit.field_ns1'] = 'Server dei nomi 1';
$lang['AdminMain.edit.field_auto_renewal'] = 'Abilita il rinnovo automatico';
$lang['AdminMain.edit.field_years'] = 'Anni';
$lang['AdminMain.edit.field_action'] = 'Azione';
$lang['AdminMain.edit.link_viewclient'] = 'Visualizza il cliente';
$lang['AdminMain.edit.boxtitle_edit'] = 'Modifica dominio: %1$s';
$lang['AdminMain.edit.boxtitle_client'] = 'Cliente #%1$s';
$lang['AdminMain.add_confirmation.discount'] = 'Sconto:';
$lang['AdminMain.add_confirmation.subtotal'] = 'Totale parziale:';
$lang['AdminMain.add_confirmation.price'] = 'Prezzo';
$lang['AdminMain.add_confirmation.qty'] = 'Quantità';
$lang['AdminMain.add_confirmation.description'] = 'Descrizione';
$lang['AdminMain.add_confirmation.type_transfer'] = 'Trasferimento';
$lang['AdminMain.add_confirmation.type_register'] = 'Registrazione';
$lang['AdminMain.add_confirmation.field_edit'] = 'Modifica';
$lang['AdminMain.add_confirmation.field_add'] = 'Aggiungi dominio';
$lang['AdminMain.add_confirmation.field_update_coupon'] = 'Aggiornamento';
$lang['AdminMain.add_confirmation.field_coupon_code'] = 'Codice coupon';
$lang['AdminMain.add_confirmation.field_price'] = 'Prezzo:';
$lang['AdminMain.add_confirmation.field_type'] = 'Tipo:';
$lang['AdminMain.add_confirmation.field_years'] = 'Anni:';
$lang['AdminMain.add_confirmation.field_domain'] = 'Dominio:';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = 'No';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = 'Sì';
$lang['AdminMain.add_confirmation.field_notify_order'] = 'Inviare l\'e-mail di conferma dell\'ordine:';
$lang['AdminMain.add_confirmation.field_module'] = 'Modulo Registrar:';
$lang['AdminMain.add_confirmation.field_status'] = 'Stato:';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = 'Non fatturare';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = 'Aggiungere alla fattura %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = 'Creare una nuova fattura';
$lang['AdminMain.add_confirmation.field_invoice_method'] = 'Metodo di fatturazione:';
$lang['AdminMain.add.edit_package_pricing'] = 'Modifica dei prezzi';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s (rinnova a %3$s)';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.order_btn'] = 'Ordine selezionato';
$lang['AdminMain.add.term_years'] = '%1$s Anni';
$lang['AdminMain.add.term_year'] = '%1$s Anno';
$lang['AdminMain.add.term_months'] = '%1$s Mesi';
$lang['AdminMain.add.term_month'] = '%1$s Mese';
$lang['AdminMain.add.term_weeks'] = '%1$s Settimane';
$lang['AdminMain.add.term_week'] = 'Settimana %1$s';
$lang['AdminMain.add.term_days'] = '%1$s Giorni';
$lang['AdminMain.add.term_day'] = 'Giorno %1$s';
$lang['AdminMain.add.text_domain_unavailable'] = 'Non disponibile';
$lang['AdminMain.add.text_domain_available'] = 'Disponibile';
$lang['AdminMain.add.heading_options'] = 'Opzioni';
$lang['AdminMain.add.heading_status'] = 'Stato';
$lang['AdminMain.add.heading_domain'] = 'Dominio';
$lang['AdminMain.add.title_registrar_options'] = 'Opzioni del conservatore';
$lang['AdminMain.add.title_basic_options'] = 'Opzioni di base';
$lang['AdminMain.add.title_search_results'] = 'Risultati della ricerca';
$lang['AdminMain.add.field_notify_order'] = 'Invia un\'e-mail di conferma dell\'ordine quando viene attivato';
$lang['AdminMain.add.field_use_module'] = 'Provisionare il dominio utilizzando il modulo della società di registrazione quando viene attivato';
$lang['AdminMain.add.field_module'] = 'Modulo Registrar';
$lang['AdminMain.add.field_status'] = 'Stato';
$lang['AdminMain.add.field_years'] = 'Anni';
$lang['AdminMain.add.field_invoice_method_dont'] = 'Non fatturare';
$lang['AdminMain.add.field_invoice_method_append'] = 'Aggiunta alla fattura esistente';
$lang['AdminMain.add.field_invoice_method_create'] = 'Creare una nuova fattura';
$lang['AdminMain.add.field_invoice_method'] = 'Metodo di fatturazione';
$lang['AdminMain.add.field_submit'] = 'Continua';
$lang['AdminMain.add.field_lookup'] = 'Verifica la disponibilità';
$lang['AdminMain.add.field_add'] = 'Aggiungi dominio';
$lang['AdminMain.add.field_register'] = 'Registro';
$lang['AdminMain.add.field_transfer'] = 'Trasferimento';
$lang['AdminMain.add.link_viewclient'] = 'Visualizza il cliente';
$lang['AdminMain.add.boxtitle_add'] = 'Aggiungi dominio: %1$s';
$lang['AdminMain.add.boxtitle_client'] = 'Cliente #%1$s';
$lang['AdminMain.index.unparent'] = 'Prezzo non genitore e prezzo di azzeramento';
$lang['AdminMain.!error.unsupported_domain'] = 'Il nome di dominio non è supportato.';
$lang['AdminMain.!success.service_edited'] = 'Il dominio è stato aggiornato con successo!';
$lang['AdminMain.!success.domain_add'] = 'Il dominio è stato aggiunto con successo!';
$lang['AdminMain.!success.domain_transfer'] = 'Il dominio è stato trasferito con successo!';
$lang['AdminMain.!success.domain_register'] = 'Il dominio è stato registrato con successo!';
$lang['AdminMain.!success.domains_unparented'] = 'I domini selezionati sono stati rimossi dai loro servizi madre e il prezzo è stato ripristinato con successo!';
$lang['AdminMain.getfilters.field_service_meta'] = 'Nome di dominio';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.any'] = 'Qualsiasi';
$lang['AdminMain.domains.action.field_client'] = 'Cliente';
$lang['AdminMain.domains.action.field_nameservers'] = 'Nameserver';
$lang['AdminMain.domains.action.field_years'] = 'Anni';
$lang['AdminMain.index.field_actionsubmit'] = 'Invia';
$lang['AdminMain.index.domain_push_to_client'] = 'Spinta al cliente';
$lang['AdminMain.index.update_nameservers'] = 'Aggiornare i server dei nomi';
$lang['AdminMain.index.domain_renewal'] = 'Rinnovo del dominio';
$lang['AdminMain.index.change_auto_renewal'] = 'Cambia il rinnovo dell\'auto';
$lang['AdminMain.index.text_off'] = 'Spento';
$lang['AdminMain.index.text_on'] = 'Su';
$lang['AdminMain.index.text_never'] = 'Mai';
$lang['AdminMain.index.no_results'] = 'Non ci sono servizi con questo status.';
$lang['AdminMain.index.confirm_delete'] = 'Siete sicuri di voler eliminare questo servizio?';
$lang['AdminMain.index.option_delete'] = 'Cancellare';
$lang['AdminMain.index.option_manage'] = 'Gestire';
$lang['AdminMain.index.option_parent'] = 'Genitore';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.categorylink_newservice'] = 'Nuovo dominio';
$lang['AdminMain.index.category_canceled'] = 'Annullato';
$lang['AdminMain.index.category_suspended'] = 'Sospeso';
$lang['AdminMain.index.category_pending'] = 'In attesa';
$lang['AdminMain.index.category_active'] = 'Attivo';
$lang['AdminMain.index.heading_options'] = 'Opzioni';
$lang['AdminMain.index.heading_datecanceled'] = 'Data di annullamento';
$lang['AdminMain.index.heading_datesuspended'] = 'Data di sospensione';
$lang['AdminMain.index.heading_dateexpires'] = 'Data di scadenza';
$lang['AdminMain.index.heading_daterenews'] = 'Data Rinnovo';
$lang['AdminMain.index.heading_datecreated'] = 'Data di creazione';
$lang['AdminMain.index.heading_term'] = 'Termine';
$lang['AdminMain.index.heading_domain'] = 'Dominio';
$lang['AdminMain.index.heading_status'] = 'Stato';
$lang['AdminMain.index.heading_addons'] = 'Componenti aggiuntivi';
$lang['AdminMain.index.boxtitle_domains'] = 'Domini';
$lang['AdminMain.index.page_title'] = 'Dominio del cliente #%1$s';
$lang['AdminMain.!success.domains_pushed'] = 'I domini selezionati sono stati trasferiti con successo al nuovo client.';
$lang['AdminMain.!success.update_nameservers'] = 'I server dei nomi di dominio sono stati aggiornati!';
$lang['AdminMain.!success.domain_renewal'] = 'Il dominio è stato rinnovato!';
$lang['AdminMain.!success.change_auto_renewal'] = 'Il rinnovo automatico del dominio è stato aggiornato!';
$lang['AdminMain.edit.text_registration_date'] = 'Data di registrazione:';
$lang['AdminMain.index.text_date_added'] = 'Data di inserimento:';
$lang['AdminMain.index.heading_dateregistration'] = 'Data di registrazione';
$lang['AdminMain.index.heading_registrar'] = 'Registrar';
$lang['AdminMain.!success.domain_registrar_updated'] = 'Il registrar del dominio è stato aggiornato!';
$lang['AdminMain.edit.field_registration_date'] = 'Modifica della data di registrazione';
$lang['AdminMain.edit.field_expiration_date'] = 'Modifica della data di scadenza';
$lang['AdminMain.!success.change_registration_date'] = 'La data di registrazione del dominio è stata aggiornata!';
$lang['AdminMain.!success.change_expiration_date'] = 'La data di scadenza del dominio è stata aggiornata!';
